@@ -1,5 +1,5 @@
 package Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes;
-$Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes::VERSION = '0.0.15';
+$Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes::VERSION = '0.106';
 # ABSTRACT: Generate valid CPAN::Changes Changelogs from git
 
 use v5.10.1;
@@ -7,7 +7,7 @@ use Moose;
 use Moose::Util::TypeConstraints;
 use Class::Load 'try_load_class';
 use CPAN::Changes::Release;
-use CPAN::Changes;
+use CPAN::Changes 0.400001;
 use DateTime;
 use Encode;
 use Git::Wrapper;
@@ -377,8 +377,8 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Ioan Rogers Alexandr Bell Bhadoria Ciornii Doug Jakob Jormola Shantanu
-Tuomas Voss
+=for :stopwords Ioan Rogers Alexandr Tuomas Voß Bell Bhadoria Ciornii Doug Jakob Jormola
+Retout Shantanu Tim
 
 =head1 NAME
 
@@ -386,7 +386,7 @@ Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes - Generate valid CPAN::Chan
 
 =head1 VERSION
 
-version 0.0.15
+version 0.106
 
 =head1 SYNOPSIS
 
